==> HTML-Menu-TreeView-0.6.3.tar.gz: HTML-Menu-TreeView-0.6.3/htdocs/style/Crystal/48/html-menu-treeview/preload.js <==
folderClosed = new Image(48,48);
folderClosed.src='/style/Crystal/48/html-menu-treeview/folderClosed.gif';
plusNodeClosed = new Image(48,48);
plusNodeClosed.src='/style/Crystal/48/html-menu-treeview/plusNodeClosed.gif';
lastPlusNodeClosed = new Image(48,48);
lastPlusNodeClosed.src='/style/Crystal/48/html-menu-treeview/lastPlusNodeClosed.gif';
clasicPlusNodeClosed = new Image(48,48);
clasicPlusNodeClosed.src='/style/Crystal/48/html-menu-treeview/clasicPlusNodeClosed.gif';
clasicLastPlusNodeClosed = new Image(48,48);
clasicLastPlusNodeClosed.src='/style/Crystal/48/html-menu-treeview/clasicLastPlusNodeClosed.gif';
folderManClosed = new Image(48,48);
folderManClosed.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(48,48);
folderGray.src='/style/Crystal/48/html-menu-treeview/folderGray.gif';
folderGreen = new Image(48,48);
folderGreen.src='/style/Crystal/48/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(48,48);
folderViolet.src='/style/Crystal/48/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(48,48);
folderYellowClosed.src='/style/Crystal/48/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(48,48);
folderOrangeClosed.src='/style/Crystal/48/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(48,48);
folderManClosed.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(48,48);
folderHtmlClosed.src='/style/Crystal/48/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(48,48);
folderFavoriteClosed.src='/style/Crystal/48/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(48,48);
folderTextClosed.src='/style/Crystal/48/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(48,48);
folderLockedClosed.src='/style/Crystal/48/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(48,48);
folderCrystalClosed.src='/style/Crystal/48/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(48,48);
folderVideoClosed.src='/style/Crystal/48/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(48,48);
folderPrintClosed.src='/style/Crystal/48/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(48,48);
folderImageClosed.src='/style/Crystal/48/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(48,48);
folderSoundClosed.src='/style/Crystal/48/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(48,48);
folderImportantClosed.src='/style/Crystal/48/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(48,48);
folderTarClosed.src='/style/Crystal/48/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.6.5.tar.gz: HTML-Menu-TreeView-0.6.5/htdocs/style/Crystal/48/html-menu-treeview/preload.js <==
folderClosed = new Image(48,48);
folderClosed.src='/style/Crystal/48/html-menu-treeview/folderClosed.gif';
plusNode = new Image(48,48);
plusNode.src='/style/Crystal/48/html-menu-treeview/plusNode.gif';
lastplusNode = new Image(48,48);
lastplusNode.src='/style/Crystal/48/html-menu-treeview/lastplusNode.gif';
clasicplusNode = new Image(48,48);
clasicplusNode.src='/style/Crystal/48/html-menu-treeview/clasicplusNode.gif';
clasicLastplusNode = new Image(48,48);
clasicLastplusNode.src='/style/Crystal/48/html-menu-treeview/clasicLastplusNode.gif';
folderManClosed = new Image(48,48);
folderManClosed.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(48,48);
folderGray.src='/style/Crystal/48/html-menu-treeview/folderGray.gif';
folderGreen = new Image(48,48);
folderGreen.src='/style/Crystal/48/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(48,48);
folderViolet.src='/style/Crystal/48/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(48,48);
folderYellowClosed.src='/style/Crystal/48/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(48,48);
folderOrangeClosed.src='/style/Crystal/48/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(48,48);
folderManClosed.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(48,48);
folderHtmlClosed.src='/style/Crystal/48/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(48,48);
folderFavoriteClosed.src='/style/Crystal/48/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(48,48);
folderTextClosed.src='/style/Crystal/48/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(48,48);
folderLockedClosed.src='/style/Crystal/48/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(48,48);
folderCrystalClosed.src='/style/Crystal/48/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(48,48);
folderVideoClosed.src='/style/Crystal/48/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(48,48);
folderPrintClosed.src='/style/Crystal/48/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(48,48);
folderImageClosed.src='/style/Crystal/48/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(48,48);
folderSoundClosed.src='/style/Crystal/48/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(48,48);
folderImportantClosed.src='/style/Crystal/48/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(48,48);
folderTarClosed.src='/style/Crystal/48/html-menu-treeview/folderTarClosed.gif';
